#pilot-notification-popup {
  -moz-appearance: none;
  background-color: Menu;
  background-image: -moz-linear-gradient(hsla(0,0%,100%,.2), transparent);
  box-shadow: inset 0 0 7px hsla(0,0%,100%,.2),
                   inset 0 1px 0 hsla(0,0%,100%,.3);
  border-radius: 4px;
  border: 1px solid Menu;
  margin: -6px 0 0 0;
  width: 480px;
}

.tail-up,
.tail-down {
 -moz-border-image: none;
}

.pilot-notification-popup-container {
  -moz-appearance: none;
  margin: 0;
  padding: 10px;
  font-size: 14px;
}
